@@ -110,7 +110,7 @@ DwaCompressor_construct (
 
     if (encode)
     {
-        const struct _internal_exr_context* pctxt = EXR_CCTXT (encode->context);
+        exr_const_context_t pctxt = encode->context;
 
         me->alloc_fn = pctxt ? pctxt->alloc_fn : internal_exr_alloc;
         me->free_fn  = pctxt ? pctxt->free_fn : internal_exr_free;
@@ -154,7 +154,7 @@ DwaCompressor_construct (
     }
     else
     {
-        const struct _internal_exr_context* pctxt = EXR_CCTXT (decode->context);
+        exr_const_context_t pctxt = decode->context;
 
         me->alloc_fn = pctxt ? pctxt->alloc_fn : internal_exr_alloc;
         me->free_fn  = pctxt ? pctxt->free_fn : internal_exr_free;
@@ -253,9 +253,8 @@ DwaCompressor_compress (DwaCompressor* me)
 
     // Starting with DWA v2, we write the channel
     // classification rules into the file
-    me->_channelRules = sDefaultChannelRules;
-    me->_channelRuleCount =
-        sizeof (sDefaultChannelRules) / sizeof (Classifier);
+    me->_channelRules     = sDefaultChannelRules;
+    me->_channelRuleCount = sizeof (sDefaultChannelRules) / sizeof (Classifier);
 
     rv = DwaCompressor_initializeBuffers (me, &outBufferSize);
 
@@ -758,8 +757,8 @@ DwaCompressor_uncompress (
                      dcCompressedSize + rleCompressedSize;
 
     dataPtrEnd = inPtr + iSize;
-    dataPtr  = inPtr + headerSize;
-    dataLeft = iSize - headerSize;
+    dataPtr    = inPtr + headerSize;
+    dataLeft   = iSize - headerSize;
 
     /* Both the sum and individual sizes are checked in case of overflow. */
     if (iSize < (headerSize + compressedSize) ||
@@ -836,12 +835,9 @@ DwaCompressor_uncompress (
     compressedDcBuf  = compressedAcBuf + (ptrdiff_t) (acCompressedSize);
     compressedRleBuf = compressedDcBuf + (ptrdiff_t) (dcCompressedSize);
 
-    if (compressedUnknownBuf > dataPtrEnd ||
-        dataPtr > compressedAcBuf ||
-        compressedAcBuf > dataPtrEnd ||
-        dataPtr > compressedDcBuf ||
-        compressedDcBuf > dataPtrEnd ||
-        dataPtr > compressedRleBuf ||
+    if (compressedUnknownBuf > dataPtrEnd || dataPtr > compressedAcBuf ||
+        compressedAcBuf > dataPtrEnd || dataPtr > compressedDcBuf ||
+        compressedDcBuf > dataPtrEnd || dataPtr > compressedRleBuf ||
         compressedRleBuf > dataPtrEnd ||
         (compressedRleBuf + rleCompressedSize) > dataPtrEnd)
     {
@@ -858,6 +854,7 @@ DwaCompressor_uncompress (
     if (version > 2) { return EXR_ERR_BAD_CHUNK_LEADER; }
 
     rv = DwaCompressor_setupChannelData (me);
+    if (rv != EXR_ERR_SUCCESS) { return rv; }
 
     //
     // Uncompress the UNKNOWN data into _planarUncBuffer[UNKNOWN]
@@ -1083,6 +1080,8 @@ DwaCompressor_uncompress (
         packedAcBufferEnd += decoder._packedAcCount * sizeof (uint16_t);
 
         packedDcBufferEnd += decoder._packedDcCount * sizeof (uint16_t);
+
+        totalAcUncompressedCount -= decoder._packedAcCount;
         totalDcUncompressedCount -= decoder._packedDcCount;
 
         me->_channelData[rChan].processed = 1;
@@ -1105,6 +1104,12 @@ DwaCompressor_uncompress (
 
         if (cd->processed) continue;
 
+        if (chan->width == 0 || chan->height == 0)
+        {
+            cd->processed = 1;
+            continue;
+        }
+
         switch (cd->compression)
         {
             case LOSSY_DCT:
@@ -1142,6 +1147,7 @@ DwaCompressor_uncompress (
                     packedDcBufferEnd +=
                         (size_t) decoder._packedDcCount * sizeof (uint16_t);
 
+                    totalAcUncompressedCount -= decoder._packedAcCount;
                     totalDcUncompressedCount -= decoder._packedDcCount;
                     if (rv != EXR_ERR_SUCCESS) { return rv; }
                 }
@@ -1604,7 +1610,7 @@ DwaCompressor_classifyChannels (DwaCompressor* me)
             prefixMap,
             me->_numChannels,
             curc->channel_name,
-            (size_t) (curc->channel_name - suffix));
+            (size_t) (suffix - curc->channel_name));
 
         for (size_t i = 0; i < me->_channelRuleCount; ++i)
         {
@@ -1703,7 +1709,7 @@ DwaCompressor_setupChannelData (DwaCompressor* me)
         {
             for (int byte = 1; byte < curc->bytes_per_element; ++byte)
             {
-                cd->planarUncRle[byte] = 0;
+                cd->planarUncRle[byte]    = 0;
                 cd->planarUncRleEnd[byte] = 0;
             }
         }
